@@ -78,6 +78,7 @@ import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.utils.MailFolderUtility;
 import com.openexchange.push.PushEventConstants;
 import com.openexchange.session.Session;
+import com.sun.mail.iap.ConnectQuotaExceededException;
 import com.sun.mail.imap.IMAPStore;
 
 /**
@@ -440,11 +441,11 @@ public final class IMAPException extends OXException {
         /**
          * No connection available to access mailbox
          */
-        NOT_CONNECTED("No connection available to access mailbox", Category.CATEGORY_ERROR, 2001),
+        NOT_CONNECTED(IMAPExceptionMessages.NOT_CONNECTED_MSG, Category.CATEGORY_ERROR, 2001),
         /**
          * No connection available to access mailbox on server %1$s with login %2$s (user=%3$s, context=%4$s)
          */
-        NOT_CONNECTED_EXT("No connection available to access mailbox on server %1$s with login %2$s (user=%3$s, context=%4$s)", NOT_CONNECTED),
+        NOT_CONNECTED_EXT(IMAPExceptionMessages.NOT_CONNECTED_EXT_MSG, NOT_CONNECTED),
         /**
          * Missing parameter %1$s
          */
@@ -460,47 +461,47 @@ public final class IMAPException extends OXException {
         /**
          * User %1$s has no mail module access due to user configuration
          */
-        NO_MAIL_MODULE_ACCESS("User %1$s has no mail module access due to user configuration", Category.CATEGORY_PERMISSION_DENIED, 2003),
+        NO_MAIL_MODULE_ACCESS(IMAPExceptionMessages.NO_MAIL_MODULE_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2003),
         /**
          * No access to mail folder %1$s
          */
-        NO_ACCESS("No access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2003),
+        NO_ACCESS(IMAPExceptionMessages.NO_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2003),
         /**
          * No access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_ACCESS_EXT("No access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_ACCESS),
+        NO_ACCESS_EXT(IMAPExceptionMessages.NO_ACCESS_EXT_MSG, NO_ACCESS),
         /**
          * No lookup access to mail folder %1$s
          */
-        NO_LOOKUP_ACCESS("No lookup access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2004),
+        NO_LOOKUP_ACCESS(IMAPExceptionMessages.NO_LOOKUP_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2004),
         /**
          * No lookup access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_LOOKUP_ACCESS_EXT("No lookup access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_LOOKUP_ACCESS),
+        NO_LOOKUP_ACCESS_EXT(IMAPExceptionMessages.NO_LOOKUP_ACCESS_EXT_MSG, NO_LOOKUP_ACCESS),
         /**
          * No read access on mail folder %1$s
          */
-        NO_READ_ACCESS("No read access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2005),
+        NO_READ_ACCESS(IMAPExceptionMessages.NO_READ_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2005),
         /**
          * No read access on mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_READ_ACCESS_EXT("No read access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_READ_ACCESS),
+        NO_READ_ACCESS_EXT(IMAPExceptionMessages.NO_READ_ACCESS_EXT_MSG, NO_READ_ACCESS),
         /**
          * No delete access on mail folder %1$s
          */
-        NO_DELETE_ACCESS("No delete access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2006),
+        NO_DELETE_ACCESS(IMAPExceptionMessages.NO_DELETE_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2006),
         /**
          * No delete access on mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DELETE_ACCESS_EXT("No delete access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DELETE_ACCESS),
+        NO_DELETE_ACCESS_EXT(IMAPExceptionMessages.NO_DELETE_ACCESS_EXT_MSG, NO_DELETE_ACCESS),
         /**
          * No insert access on mail folder %1$s
          */
-        NO_INSERT_ACCESS("No insert access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2007),
+        NO_INSERT_ACCESS(IMAPExceptionMessages.NO_INSERT_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2007),
         /**
          * No insert access on mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_INSERT_ACCESS_EXT("No insert access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_INSERT_ACCESS),
+        NO_INSERT_ACCESS_EXT(IMAPExceptionMessages.NO_INSERT_ACCESS_EXT_MSG, NO_INSERT_ACCESS),
         /**
          * No create access on mail folder %1$s
          */
@@ -512,35 +513,35 @@ public final class IMAPException extends OXException {
         /**
          * No administer access on mail folder %1$s
          */
-        NO_ADMINISTER_ACCESS("No administer access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2009),
+        NO_ADMINISTER_ACCESS(IMAPExceptionMessages.NO_ADMINISTER_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2009),
         /**
          * No administer access on mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_ADMINISTER_ACCESS_EXT("No administer access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_ADMINISTER_ACCESS),
+        NO_ADMINISTER_ACCESS_EXT(IMAPExceptionMessages.NO_ADMINISTER_ACCESS_EXT_MSG, NO_ADMINISTER_ACCESS),
         /**
          * No write access to IMAP folder %1$s
          */
-        NO_WRITE_ACCESS("No write access to IMAP folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2010),
+        NO_WRITE_ACCESS(IMAPExceptionMessages.NO_WRITE_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2010),
         /**
          * No write access to IMAP folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_WRITE_ACCESS_EXT("No write access to IMAP folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_WRITE_ACCESS),
+        NO_WRITE_ACCESS_EXT(IMAPExceptionMessages.NO_WRITE_ACCESS_EXT_MSG, NO_WRITE_ACCESS),
         /**
          * No keep-seen access on mail folder %1$s
          */
-        NO_KEEP_SEEN_ACCESS("No keep-seen access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2011),
+        NO_KEEP_SEEN_ACCESS(IMAPExceptionMessages.NO_KEEP_SEEN_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2011),
         /**
          * No keep-seen access on mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_KEEP_SEEN_ACCESS_EXT("No keep-seen access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_KEEP_SEEN_ACCESS),
+        NO_KEEP_SEEN_ACCESS_EXT(IMAPExceptionMessages.NO_KEEP_SEEN_ACCESS_EXT_MSG, NO_KEEP_SEEN_ACCESS),
         /**
          * Folder %1$s does not allow subfolders.
          */
-        FOLDER_DOES_NOT_HOLD_FOLDERS("Folder %1$s does not allow subfolders.", Category.CATEGORY_PERMISSION_DENIED, 2012),
+        FOLDER_DOES_NOT_HOLD_FOLDERS(IMAPExceptionMessages.FOLDER_DOES_NOT_HOLD_FOLDERS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2012),
         /**
          * Folder %1$s does not allow subfolders on server %2$s with login %3$s (user=%4$s, context=%5$s).
          */
-        FOLDER_DOES_NOT_HOLD_FOLDERS_EXT("Folder %1$s does not allow subfolders on server %2$s with login %3$s (user=%4$s, context=%5$s).", FOLDER_DOES_NOT_HOLD_FOLDERS),
+        FOLDER_DOES_NOT_HOLD_FOLDERS_EXT(IMAPExceptionMessages.FOLDER_DOES_NOT_HOLD_FOLDERS_EXT_MSG, FOLDER_DOES_NOT_HOLD_FOLDERS),
         /**
          * Invalid folder name: "%1$s"
          */
@@ -557,86 +558,86 @@ public final class IMAPException extends OXException {
          * Mail folder "%1$s" could not be created (maybe due to insufficient permission on parent folder %2$s or due to an invalid folder
          * name)
          */
-        FOLDER_CREATION_FAILED("Mail folder \"%1$s\" could not be created (maybe due to insufficient permission on parent folder %2$s or due to an invalid folder name)", Category.CATEGORY_USER_INPUT, 2015),
+        FOLDER_CREATION_FAILED(IMAPExceptionMessages.FOLDER_CREATION_FAILED_MSG, Category.CATEGORY_USER_INPUT, 2015),
         /**
          * Mail folder "%1$s" could not be created (maybe due to insufficient permission on parent folder %2$s or due to an invalid folder
          * name) on server %3$s with login %4$s (user=%5$s, context=%6$s)
          */
-        FOLDER_CREATION_FAILED_EXT("Mail folder \"%1$s\" could not be created (maybe due to insufficient permission on parent folder %2$s or due to an invalid folder name) on server %3$s with login %4$s (user=%5$s, context=%6$s)", FOLDER_CREATION_FAILED),
+        FOLDER_CREATION_FAILED_EXT(IMAPExceptionMessages.FOLDER_CREATION_FAILED_EXT_MSG, FOLDER_CREATION_FAILED),
         /**
          * The composed rights could not be applied to new folder %1$s due to missing administer right in its initial rights specified by
          * IMAP server. However, the folder has been created.
          */
-        NO_ADMINISTER_ACCESS_ON_INITIAL("The composed rights could not be applied to new folder %1$s due to missing administer right in its initial rights specified by IMAP server. However, the folder has been created.", Category.CATEGORY_PERMISSION_DENIED, 2016),
+        NO_ADMINISTER_ACCESS_ON_INITIAL(IMAPExceptionMessages.NO_ADMINISTER_ACCESS_ON_INITIAL_MSG, Category.CATEGORY_PERMISSION_DENIED, 2016),
         /**
          * The composed rights could not be applied to new folder %1$s due to missing administer right in its initial rights specified by
          * IMAP server. However, the folder has been created on server %2$s with login %3$s (user=%4$s, context=%5$s).
          */
-        NO_ADMINISTER_ACCESS_ON_INITIAL_EXT("The composed rights could not be applied to new folder %1$s due to missing administer right in its initial rights specified by IMAP server. However, the folder has been created on server %2$s with login %3$s (user=%4$s, context=%5$s).", NO_ADMINISTER_ACCESS_ON_INITIAL),
+        NO_ADMINISTER_ACCESS_ON_INITIAL_EXT(IMAPExceptionMessages.NO_ADMINISTER_ACCESS_ON_INITIAL_EXT_MSG, NO_ADMINISTER_ACCESS_ON_INITIAL),
         /**
          * No admin permission specified for folder %1$s
          */
-        NO_ADMIN_ACL("No administer permission specified for folder %1$s", Category.CATEGORY_USER_INPUT, 2017),
+        NO_ADMIN_ACL(IMAPExceptionMessages.NO_ADMIN_ACL_MSG, Category.CATEGORY_USER_INPUT, 2017),
         /**
          * No admin permission specified for folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_ADMIN_ACL_EXT("No administer permission specified for folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_ADMIN_ACL),
+        NO_ADMIN_ACL_EXT(IMAPExceptionMessages.NO_ADMIN_ACL_EXT_MSG, NO_ADMIN_ACL),
         /**
          * Default folder %1$s must not be updated
          */
-        NO_DEFAULT_FOLDER_UPDATE("Default folder %1$s must not be updated", Category.CATEGORY_PERMISSION_DENIED, 2018),
+        NO_DEFAULT_FOLDER_UPDATE(IMAPExceptionMessages.NO_DEFAULT_FOLDER_UPDATE_MSG, Category.CATEGORY_PERMISSION_DENIED, 2018),
         /**
          * Default folder %1$s must not be updated on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DEFAULT_FOLDER_UPDATE_EXT("Default folder %1$s must not be updated on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_UPDATE),
+        NO_DEFAULT_FOLDER_UPDATE_EXT(IMAPExceptionMessages.NO_DEFAULT_FOLDER_UPDATE_EXT_MSG, NO_DEFAULT_FOLDER_UPDATE),
         /**
          * Deletion of folder %1$s failed
          */
-        DELETE_FAILED("Deletion of folder %1$s failed", Category.CATEGORY_ERROR, 2019),
+        DELETE_FAILED(IMAPExceptionMessages.DELETE_FAILED_MSG, Category.CATEGORY_ERROR, 2019),
         /**
          * Deletion of folder %1$s failed on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        DELETE_FAILED_EXT("Deletion of folder %1$s failed on server %2$s with login %3$s (user=%4$s, context=%5$s)", DELETE_FAILED),
+        DELETE_FAILED_EXT(IMAPExceptionMessages.DELETE_FAILED_EXT_MSG, DELETE_FAILED),
         /**
          * IMAP default folder %1$s could not be created
          */
-        NO_DEFAULT_FOLDER_CREATION("IMAP default folder %1$s could not be created", Category.CATEGORY_ERROR, 2020),
+        NO_DEFAULT_FOLDER_CREATION(IMAPExceptionMessages.NO_DEFAULT_FOLDER_CREATION_MSG, Category.CATEGORY_ERROR, 2020),
         /**
          * IMAP default folder %1$s could not be created on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DEFAULT_FOLDER_CREATION_EXT("IMAP default folder %1$s could not be created on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_CREATION),
+        NO_DEFAULT_FOLDER_CREATION_EXT(IMAPExceptionMessages.NO_DEFAULT_FOLDER_CREATION_EXT_MSG, NO_DEFAULT_FOLDER_CREATION),
         /**
          * Missing default %1$s folder
          */
-        MISSING_DEFAULT_FOLDER_NAME("Missing default %1$s folder", Category.CATEGORY_ERROR, 2021),
+        MISSING_DEFAULT_FOLDER_NAME(IMAPExceptionMessages.MISSING_DEFAULT_FOLDER_NAME_MSG, Category.CATEGORY_ERROR, 2021),
         /**
          * Missing default %1$s folder on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        MISSING_DEFAULT_FOLDER_NAME_EXT("Missing default %1$s folder on server %2$s with login %3$s (user=%4$s, context=%5$s)", MISSING_DEFAULT_FOLDER_NAME),
+        MISSING_DEFAULT_FOLDER_NAME_EXT(IMAPExceptionMessages.MISSING_DEFAULT_FOLDER_NAME_EXT_MSG, MISSING_DEFAULT_FOLDER_NAME),
         /**
          * Update of folder %1$s failed
          */
-        UPDATE_FAILED("Update of folder %1$s failed", Category.CATEGORY_ERROR, 2022),
+        UPDATE_FAILED(IMAPExceptionMessages.UPDATE_FAILED_MSG, Category.CATEGORY_ERROR, 2022),
         /**
          * Update of folder %1$s failed on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        UPDATE_FAILED_EXT("Update of folder %1$s failed on server %2$s with login %3$s (user=%4$s, context=%5$s)", UPDATE_FAILED),
+        UPDATE_FAILED_EXT(IMAPExceptionMessages.UPDATE_FAILED_EXT_MSG, UPDATE_FAILED),
         /**
          * Folder %1$s must not be deleted
          */
-        NO_FOLDER_DELETE("Folder %1$s cannot be deleted", Category.CATEGORY_PERMISSION_DENIED, 2023),
+        NO_FOLDER_DELETE(IMAPExceptionMessages.NO_FOLDER_DELETE_MSG, Category.CATEGORY_PERMISSION_DENIED, 2023),
         /**
          * Folder %1$s must not be deleted on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_FOLDER_DELETE_EXT("Folder %1$s cannot be deleted on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_FOLDER_DELETE),
+        NO_FOLDER_DELETE_EXT(IMAPExceptionMessages.NO_FOLDER_DELETE_EXT_MSG, NO_FOLDER_DELETE),
         /**
          * Default folder %1$s must not be deleted
          */
-        NO_DEFAULT_FOLDER_DELETE("Default folder %1$s cannot be deleted", Category.CATEGORY_PERMISSION_DENIED, 2024),
+        NO_DEFAULT_FOLDER_DELETE(IMAPExceptionMessages.NO_DEFAULT_FOLDER_DELETE_MSG, Category.CATEGORY_PERMISSION_DENIED, 2024),
         /**
          * Default folder %1$s must not be deleted on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DEFAULT_FOLDER_DELETE_EXT("Default folder %1$s cannot be deleted on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_DELETE),
+        NO_DEFAULT_FOLDER_DELETE_EXT(IMAPExceptionMessages.NO_DEFAULT_FOLDER_DELETE_EXT_MSG, NO_DEFAULT_FOLDER_DELETE),
         /**
          * An I/O error occurred: %1$s
          */
@@ -644,11 +645,11 @@ public final class IMAPException extends OXException {
         /**
          * Flag %1$s could not be changed due to reason "%2$s"
          */
-        FLAG_FAILED("Flag %1$s could not be changed due to following reason \"%2$s\"", Category.CATEGORY_ERROR, 2025),
+        FLAG_FAILED(IMAPExceptionMessages.FLAG_FAILED_MSG, Category.CATEGORY_ERROR, 2025),
         /**
          * Flag %1$s could not be changed due to reason "%2$s" on server %3$s with login %4$s (user=%5$s, context=%6$s)
          */
-        FLAG_FAILED_EXT("Flag %1$s could not be changed due to following reason \"%2$s\" on server %3$s with login %4$s (user=%5$s, context=%6$s)", FLAG_FAILED),
+        FLAG_FAILED_EXT(IMAPExceptionMessages.FLAG_FAILED_EXT_MSG, FLAG_FAILED),
         /**
          * Folder %1$s does not hold messages and is therefore not selectable
          */
@@ -660,33 +661,33 @@ public final class IMAPException extends OXException {
         /**
          * Number of search fields (%d) do not match number of search patterns (%d)
          */
-        INVALID_SEARCH_PARAMS("Number of search fields (%d) do not match number of search patterns (%d)", Category.CATEGORY_ERROR, 2028),
+        INVALID_SEARCH_PARAMS(IMAPExceptionMessages.INVALID_SEARCH_PARAMS_MSG, Category.CATEGORY_ERROR, 2028),
         /**
          * IMAP search failed due to reason "%1$s". Switching to application-based search
          */
-        IMAP_SEARCH_FAILED("IMAP search failed due to reason \"%1$s\". Switching to application-based search", Category.CATEGORY_SERVICE_DOWN, 2029),
+        IMAP_SEARCH_FAILED(IMAPExceptionMessages.IMAP_SEARCH_FAILED_MSG, Category.CATEGORY_SERVICE_DOWN, 2029),
         /**
          * IMAP search failed due to reason "%1$s" on server %2$s with login %3$s (user=%4$s, context=%5$s). Switching to application-based
          * search.
          */
-        IMAP_SEARCH_FAILED_EXT("IMAP search failed due to reason \"%1$s\" on server %2$s with login %3$s (user=%4$s, context=%5$s). Switching to application-based search.", IMAP_SEARCH_FAILED),
+        IMAP_SEARCH_FAILED_EXT(IMAPExceptionMessages.IMAP_SEARCH_FAILED_EXT_MSG, IMAP_SEARCH_FAILED),
         /**
          * IMAP sort failed due to reason "%1$s". Switching to application-based sorting.
          */
-        IMAP_SORT_FAILED("IMAP sort failed due to reason \"%1$s\". Switching to application-based sorting.", Category.CATEGORY_SERVICE_DOWN, 2030),
+        IMAP_SORT_FAILED(IMAPExceptionMessages.IMAP_SORT_FAILED_MSG, Category.CATEGORY_SERVICE_DOWN, 2030),
         /**
          * IMAP sort failed due to reason "%1$s" on server %2$s with login %3$s (user=%4$s, context=%5$s). Switching to application-based
          * sorting.
          */
-        IMAP_SORT_FAILED_EXT("IMAP sort failed due to reason \"%1$s\" on server %2$s with login %3$s (user=%4$s, context=%5$s). Switching to application-based sorting.", IMAP_SORT_FAILED),
+        IMAP_SORT_FAILED_EXT(IMAPExceptionMessages.IMAP_SORT_FAILED_EXT_MSG, IMAP_SORT_FAILED),
         /**
          * Unknown search field: %1$s
          */
-        UNKNOWN_SEARCH_FIELD("Unknown search field: %1$s", Category.CATEGORY_ERROR, 2031),
+        UNKNOWN_SEARCH_FIELD(IMAPExceptionMessages.UNKNOWN_SEARCH_FIELD_MSG, Category.CATEGORY_ERROR, 2031),
         /**
          * Unknown search field: %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        UNKNOWN_SEARCH_FIELD_EXT("Unknown search field: %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", UNKNOWN_SEARCH_FIELD),
+        UNKNOWN_SEARCH_FIELD_EXT(IMAPExceptionMessages.UNKNOWN_SEARCH_FIELD_EXT_MSG, UNKNOWN_SEARCH_FIELD),
         /**
          * Message field %1$s cannot be handled
          */
@@ -698,87 +699,87 @@ public final class IMAPException extends OXException {
         /**
          * Mail folder %1$s must not be moved to subsequent folder %2$s
          */
-        NO_MOVE_TO_SUBFLD("Mail folder %1$s must not be moved to subsequent folder %2$s", Category.CATEGORY_PERMISSION_DENIED, 2032),
+        NO_MOVE_TO_SUBFLD(IMAPExceptionMessages.NO_MOVE_TO_SUBFLD_MSG, Category.CATEGORY_PERMISSION_DENIED, 2032),
         /**
          * Mail folder %1$s must not be moved to subsequent folder %2$s on server %3$s with login %4$s (user=%5$s, context=%6$s)
          */
-        NO_MOVE_TO_SUBFLD_EXT("Mail folder %1$s must not be moved to subsequent folder %2$s on server %3$s with login %4$s (user=%5$s, context=%6$s)", NO_MOVE_TO_SUBFLD),
+        NO_MOVE_TO_SUBFLD_EXT(IMAPExceptionMessages.NO_MOVE_TO_SUBFLD_EXT_MSG, NO_MOVE_TO_SUBFLD),
         /**
          * This message could not be moved to trash folder, possibly because your mailbox is nearly full.<br>
          * In that case, please try to empty your deleted items first, or delete smaller messages first.
          */
-        MOVE_ON_DELETE_FAILED("This message could not be moved to trash folder, possibly because your mailbox is nearly full.\nIn that case, please try to empty your deleted items first, or delete smaller messages first.", Category.CATEGORY_CAPACITY, 2034),
+        MOVE_ON_DELETE_FAILED(IMAPExceptionMessages.MOVE_ON_DELETE_FAILED_MSG, Category.CATEGORY_CAPACITY, 2034),
         /**
          * This message could not be moved to trash folder on server %1$s with login %2$s (user=%3$s, context=%4$s), possibly because your mailbox is nearly full.<br>
          * In that case, please try to empty your deleted items first, or delete smaller messages first.
          */
-        MOVE_ON_DELETE_FAILED_EXT("This message could not be moved to trash folder on server %1$s with login %2$s (user=%3$s, context=%4$s), possibly because your mailbox is nearly full.\nIn that case, please try to empty your deleted items first, or delete smaller messages first.", MOVE_ON_DELETE_FAILED),
+        MOVE_ON_DELETE_FAILED_EXT(IMAPExceptionMessages.MOVE_ON_DELETE_FAILED_EXT_MSG, MOVE_ON_DELETE_FAILED),
         /**
          * Missing %1$s folder in mail move operation
          */
-        MISSING_SOURCE_TARGET_FOLDER_ON_MOVE("Missing %1$s folder in mail move operation", Category.CATEGORY_ERROR, 2035),
+        MISSING_SOURCE_TARGET_FOLDER_ON_MOVE(IMAPExceptionMessages.MISSING_SOURCE_TARGET_FOLDER_ON_MOVE_MSG, Category.CATEGORY_ERROR, 2035),
         /**
          * Missing %1$s folder in mail move operation on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        MISSING_SOURCE_TARGET_FOLDER_ON_MOVE_EXT("Missing %1$s folder in mail move operation on server %2$s with login %3$s (user=%4$s, context=%5$s)", MISSING_SOURCE_TARGET_FOLDER_ON_MOVE),
+        MISSING_SOURCE_TARGET_FOLDER_ON_MOVE_EXT(IMAPExceptionMessages.MISSING_SOURCE_TARGET_FOLDER_ON_MOVE_EXT_MSG, MISSING_SOURCE_TARGET_FOLDER_ON_MOVE),
         /**
          * Message move aborted for user %1$s. Source and destination folder are equal to "%2$s"
          */
-        NO_EQUAL_MOVE("Message move aborted for user %1$s. Source and destination folder are equal to \"%2$s\"", Category.CATEGORY_USER_INPUT, 2036),
+        NO_EQUAL_MOVE(IMAPExceptionMessages.NO_EQUAL_MOVE_MSG, Category.CATEGORY_USER_INPUT, 2036),
         /**
          * Message move aborted for user %1$s. Source and destination folder are equal to "%2$s" on server %3$s with login %4$s (user=%5$s,
          * context=%6$s)
          */
-        NO_EQUAL_MOVE_EXT("Message move aborted for user %1$s. Source and destination folder are equal to \"%2$s\" on server %3$s with login %4$s (user=%5$s, context=%6$s)", NO_EQUAL_MOVE),
+        NO_EQUAL_MOVE_EXT(IMAPExceptionMessages.NO_EQUAL_MOVE_EXT_MSG, NO_EQUAL_MOVE),
         /**
          * Folder read-only check failed
          */
-        FAILED_READ_ONLY_CHECK("IMAP folder read-only check failed", Category.CATEGORY_ERROR, 2037),
+        FAILED_READ_ONLY_CHECK(IMAPExceptionMessages.FAILED_READ_ONLY_CHECK_MSG, Category.CATEGORY_ERROR, 2037),
         /**
          * Folder read-only check failed on server %1$s with login %2$s (user=%3$s, context=%4$s)
          */
-        FAILED_READ_ONLY_CHECK_EXT("Folder read-only check failed on server %1$s with login %2$s (user=%3$s, context=%4$s)", FAILED_READ_ONLY_CHECK),
+        FAILED_READ_ONLY_CHECK_EXT(IMAPExceptionMessages.FAILED_READ_ONLY_CHECK_EXT_MSG, FAILED_READ_ONLY_CHECK),
         /**
          * Unknown folder open mode %1$s
          */
-        UNKNOWN_FOLDER_MODE("Unknown folder open mode %1$s", Category.CATEGORY_ERROR, 2038),
+        UNKNOWN_FOLDER_MODE(IMAPExceptionMessages.UNKNOWN_FOLDER_MODE_MSG, Category.CATEGORY_ERROR, 2038),
         /**
          * Unknown folder open mode %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        UNKNOWN_FOLDER_MODE_EXT("Unknown folder open mode %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", UNKNOWN_FOLDER_MODE),
+        UNKNOWN_FOLDER_MODE_EXT(IMAPExceptionMessages.UNKNOWN_FOLDER_MODE_EXT_MSG, UNKNOWN_FOLDER_MODE),
         /**
          * Message(s) %1$s in folder %2$s could not be deleted due to error "%3$s"
          */
-        UID_EXPUNGE_FAILED("Message(s) %1$s in folder %2$s could not be deleted due to error \"%3$s\"", Category.CATEGORY_ERROR, 2039),
+        UID_EXPUNGE_FAILED(IMAPExceptionMessages.UID_EXPUNGE_FAILED_MSG, Category.CATEGORY_ERROR, 2039),
         /**
          * Message(s) %1$s in folder %2$s could not be deleted due to error "%3$s" on server %4$s with login %5$s (user=%6$s, context=%7$s)
          */
-        UID_EXPUNGE_FAILED_EXT("Message(s) %1$s in folder %2$s could not be deleted due to error \"%3$s\" on server %4$s with login %5$s (user=%6$s, context=%7$s)", UID_EXPUNGE_FAILED),
+        UID_EXPUNGE_FAILED_EXT(IMAPExceptionMessages.UID_EXPUNGE_FAILED_EXT_MSG, UID_EXPUNGE_FAILED),
         /**
          * Not allowed to open folder %1$s due to missing read access
          */
-        NO_FOLDER_OPEN("Not allowed to open folder %1$s due to missing read access", Category.CATEGORY_PERMISSION_DENIED, 2041),
+        NO_FOLDER_OPEN(IMAPExceptionMessages.NO_FOLDER_OPEN_MSG, Category.CATEGORY_PERMISSION_DENIED, 2041),
         /**
          * Not allowed to open folder %1$s due to missing read access on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_FOLDER_OPEN_EXT("Not allowed to open folder %1$s due to missing read access on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_FOLDER_OPEN),
+        NO_FOLDER_OPEN_EXT(IMAPExceptionMessages.NO_FOLDER_OPEN_EXT_MSG, NO_FOLDER_OPEN),
         /**
          * The raw content's input stream of message %1$s in folder %2$s cannot be read
          */
-        MESSAGE_CONTENT_ERROR("The raw content's input stream of message %1$s in folder %2$s cannot be read", Category.CATEGORY_ERROR, 2042),
+        MESSAGE_CONTENT_ERROR(IMAPExceptionMessages.MESSAGE_CONTENT_ERROR_MSG, Category.CATEGORY_ERROR, 2042),
         /**
          * The raw content's input stream of message %1$s in folder %2$s cannot be read on server %3$s with login %4$s (user=%5$s,
          * context=%6$s)
          */
-        MESSAGE_CONTENT_ERROR_EXT("The raw content's input stream of message %1$s in folder %2$s cannot be read on server %3$s with login %4$s (user=%5$s, context=%6$s)", MESSAGE_CONTENT_ERROR),
+        MESSAGE_CONTENT_ERROR_EXT(IMAPExceptionMessages.MESSAGE_CONTENT_ERROR_EXT_MSG, MESSAGE_CONTENT_ERROR),
         /**
          * No attachment was found with id %1$s in message
          */
-        NO_ATTACHMENT_FOUND("No attachment was found with id %1$s in message", Category.CATEGORY_USER_INPUT, 2043),
+        NO_ATTACHMENT_FOUND(IMAPExceptionMessages.NO_ATTACHMENT_FOUND_MSG, Category.CATEGORY_USER_INPUT, 2043),
         /**
          * No attachment was found with id %1$s in message on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_ATTACHMENT_FOUND_EXT("No attachment was found with id %1$s in message on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_ATTACHMENT_FOUND),
+        NO_ATTACHMENT_FOUND_EXT(IMAPExceptionMessages.NO_ATTACHMENT_FOUND_EXT_MSG, NO_ATTACHMENT_FOUND),
         /**
          * Versit attachment could not be saved due to an unsupported MIME type: %1$s
          */
@@ -786,15 +787,15 @@ public final class IMAPException extends OXException {
         /**
          * Versit object %1$s could not be saved
          */
-        FAILED_VERSIT_SAVE("Versit object could not be saved", Category.CATEGORY_ERROR, 2045),
+        FAILED_VERSIT_SAVE(IMAPExceptionMessages.FAILED_VERSIT_SAVE_MSG, Category.CATEGORY_ERROR, 2045),
         /**
          * No support of capability "THREAD=REFERENCES"
          */
-        THREAD_SORT_NOT_SUPPORTED("No support of capability \"THREAD=REFERENCES\"", Category.CATEGORY_ERROR, 2046),
+        THREAD_SORT_NOT_SUPPORTED(IMAPExceptionMessages.THREAD_SORT_NOT_SUPPORTED_MSG, Category.CATEGORY_ERROR, 2046),
         /**
          * No support of capability "THREAD=REFERENCES" on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        THREAD_SORT_NOT_SUPPORTED_EXT("No support of capability \"THREAD=REFERENCES\" on server %2$s with login %3$s (user=%4$s, context=%5$s)", THREAD_SORT_NOT_SUPPORTED),
+        THREAD_SORT_NOT_SUPPORTED_EXT(IMAPExceptionMessages.THREAD_SORT_NOT_SUPPORTED_EXT_MSG, THREAD_SORT_NOT_SUPPORTED),
         /**
          * Unsupported charset-encoding: %1$s
          */
@@ -803,7 +804,7 @@ public final class IMAPException extends OXException {
          * A protocol exception occurred during execution of IMAP request "%1$s".<br>
          * Error message: %2$s
          */
-        PROTOCOL_ERROR("A protocol exception occurred during execution of IMAP request \"%1$s\".\nError message: %2$s", Category.CATEGORY_ERROR, 2047),
+        PROTOCOL_ERROR(IMAPExceptionMessages.PROTOCOL_ERROR_MSG, Category.CATEGORY_ERROR, 2047),
         /**
          * Mail folder "%1$s" could not be found.
          */
@@ -827,67 +828,67 @@ public final class IMAPException extends OXException {
         /**
          * Mailbox' root folder must not be source or the destination full name of a move operation.
          */
-        NO_ROOT_MOVE("Mailbox' root folder must not be source or the destination full name of a move operation.", Category.CATEGORY_ERROR, 2048),
+        NO_ROOT_MOVE(IMAPExceptionMessages.NO_ROOT_MOVE_MSG, Category.CATEGORY_ERROR, 2048),
         /**
          * Sort field %1$s is not supported via IMAP SORT command
          */
-        UNSUPPORTED_SORT_FIELD("Sort field %1$s is not supported via IMAP SORT command", Category.CATEGORY_ERROR, 2049),
+        UNSUPPORTED_SORT_FIELD(IMAPExceptionMessages.UNSUPPORTED_SORT_FIELD_MSG, Category.CATEGORY_ERROR, 2049),
         /**
          * Sort field %1$s is not supported via IMAP SORT command on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        UNSUPPORTED_SORT_FIELD_EXT("Sort field %1$s is not supported via IMAP SORT command on server %2$s with login %3$s (user=%4$s, context=%5$s)", UNSUPPORTED_SORT_FIELD),
+        UNSUPPORTED_SORT_FIELD_EXT(IMAPExceptionMessages.UNSUPPORTED_SORT_FIELD_EXT_MSG, UNSUPPORTED_SORT_FIELD),
         /**
          * Missing personal namespace
          */
-        MISSING_PERSONAL_NAMESPACE("Missing personal namespace", Category.CATEGORY_ERROR, 2050),
+        MISSING_PERSONAL_NAMESPACE(IMAPExceptionMessages.MISSING_PERSONAL_NAMESPACE_MSG, Category.CATEGORY_ERROR, 2050),
         /**
          * Parsing thread-sort string failed: %1$s.
          */
-        THREAD_SORT_PARSING_ERROR("Parsing thread-sort string failed: %1$s.", Category.CATEGORY_ERROR, 2051),
+        THREAD_SORT_PARSING_ERROR(IMAPExceptionMessages.THREAD_SORT_PARSING_ERROR_MSG, Category.CATEGORY_ERROR, 2051),
         /**
          * A SQL error occurred: %1$s
          */
-        SQL_ERROR("A SQL error occurred: %1$s", Category.CATEGORY_ERROR, 2052),
+        SQL_ERROR(IMAPExceptionMessages.SQL_ERROR_MSG, Category.CATEGORY_ERROR, 2052),
         /**
          * Rename of folder "%1$s" to "%2$s" failed with "%3$s".
          */
-        RENAME_FAILED("Rename of folder \"%1$s\" to \"%2$s\" failed with \"%3$s\".", Category.CATEGORY_ERROR, 2053),
+        RENAME_FAILED(IMAPExceptionMessages.RENAME_FAILED_MSG, Category.CATEGORY_ERROR, 2053),
         /**
          * Rename of folder "%1$s" to "%2$s" failed on server %3$s with login %4$s (user=%5$s, context=%6$s).
          */
-        RENAME_FAILED_EXT("Rename of folder \"%1$s\" to \"%2$s\" failed with \"%3$s\" on server %4$s with login %5$s (user=%6$s, context=%7$s).", RENAME_FAILED),
+        RENAME_FAILED_EXT(IMAPExceptionMessages.RENAME_FAILED_EXT_MSG, RENAME_FAILED),
         /**
          * No rename access to mail folder %1$s
          */
-        NO_RENAME_ACCESS("No rename access to mail folder %1$s", Category.CATEGORY_PERMISSION_DENIED, 2054),
+        NO_RENAME_ACCESS(IMAPExceptionMessages.NO_RENAME_ACCESS_MSG, Category.CATEGORY_PERMISSION_DENIED, 2054),
         /**
          * No rename access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_RENAME_ACCESS_EXT("No rename access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_RENAME_ACCESS),
+        NO_RENAME_ACCESS_EXT(IMAPExceptionMessages.NO_RENAME_ACCESS_EXT_MSG, NO_RENAME_ACCESS),
         /**
          * Unable to parse IMAP server URI "%1$s".
          */
-        URI_PARSE_FAILED("Unable to parse IMAP server URI \"%1$s\".", Category.CATEGORY_CONFIGURATION, 2055),
+        URI_PARSE_FAILED(IMAPExceptionMessages.URI_PARSE_FAILED_MSG, Category.CATEGORY_CONFIGURATION, 2055),
         /**
          * Default folder %1$s must not be unsubscribed.
          */
-        NO_DEFAULT_FOLDER_UNSUBSCRIBE("Default folder %1$s must not be unsubscribed.", Category.CATEGORY_USER_INPUT, 2056),
+        NO_DEFAULT_FOLDER_UNSUBSCRIBE(IMAPExceptionMessages.NO_DEFAULT_FOLDER_UNSUBSCRIBE_MSG, Category.CATEGORY_USER_INPUT, 2056),
         /**
          * Default folder %1$s must not be unsubscribed on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DEFAULT_FOLDER_UNSUBSCRIBE_EXT("Default folder %1$s must not be unsubscribed on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_UNSUBSCRIBE),
+        NO_DEFAULT_FOLDER_UNSUBSCRIBE_EXT(IMAPExceptionMessages.NO_DEFAULT_FOLDER_UNSUBSCRIBE_EXT_MSG, NO_DEFAULT_FOLDER_UNSUBSCRIBE),
         /**
          * IMAP server refuses to import one or more E-Mails.
          */
-        INVALID_MESSAGE("IMAP server refuses to import one or more E-Mails.", Category.CATEGORY_USER_INPUT, 2057),
+        INVALID_MESSAGE(IMAPExceptionMessages.INVALID_MESSAGE_MSG, Category.CATEGORY_USER_INPUT, 2057),
         /**
          * IMAP server %1$s refuses to import one or more E-Mails with login %2$s (user=%3$s, context=%3$s)
          */
-        INVALID_MESSAGE_EXT("IMAP server %1$s refuses to import one or more E-Mails with login %2$s (user=%3$s, context=%4$s)", INVALID_MESSAGE),
+        INVALID_MESSAGE_EXT(IMAPExceptionMessages.INVALID_MESSAGE_EXT_MSG, INVALID_MESSAGE),
         /**
          * Currently not possible to establish a new connection to server %1$s with login %2$s. Please try again.
          */
-        CONNECTION_UNAVAILABLE("Currently not possible to establish a new connection to server %1$s with login %2$s. Please try again.", Category.CATEGORY_TRY_AGAIN, 2058),
+        CONNECTION_UNAVAILABLE(IMAPExceptionMessages.CONNECTION_UNAVAILABLE_MSG, Category.CATEGORY_TRY_AGAIN, 2058),
 
         ;
 
@@ -1154,6 +1155,11 @@ public final class IMAPException extends OXException {
      */
     public static OXException handleMessagingException(final MessagingException e, final MailConfig mailConfig, final Session session, final Folder folder, final int accountId, final Map<String, Object> optProps) {
         if (null == session) {
+            if (e.getNextException() instanceof ConnectQuotaExceededException) {
+                final String server = null == mailConfig ? "<unknown>" : mailConfig.getServer();
+                final String login = null == mailConfig ? "<unknown>" : mailConfig.getLogin();
+                return IMAPException.create(IMAPException.Code.CONNECTION_UNAVAILABLE, e.getNextException(), server, login);
+            }
             // Delegate to MIME handling
             return MimeMailException.handleMessagingException(e, mailConfig, session, folder);
         }
@@ -1188,6 +1194,11 @@ public final class IMAPException extends OXException {
                 return MailExceptionCode.FOLDER_NOT_FOUND.create(e, fullName);
             }
         }
+        if (e.getNextException() instanceof ConnectQuotaExceededException) {
+            final String server = null == mailConfig ? "<unknown>" : mailConfig.getServer();
+            final String login = null == mailConfig ? "<unknown>" : mailConfig.getLogin();
+            return IMAPException.create(IMAPException.Code.CONNECTION_UNAVAILABLE, e.getNextException(), server, login);
+        }
         // Delegate to MIME handling
         return MimeMailException.handleMessagingException(e, mailConfig, session, folder);
     }
