@@ -71,6 +71,7 @@ import com.openexchange.imap.cache.RightsCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.notify.internal.IMAPNotifierMessageRecentListener;
 import com.openexchange.imap.services.Services;
+import com.openexchange.java.StringAllocator;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.api.MailMessageStorage;
 import com.openexchange.mail.api.enhanced.MailMessageStorageLong;
@@ -142,7 +143,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         if (null == imapStore || null == fullName) {
             return;
         }
-        final String key = fullName + '@' + imapStore.toString();
+        final String key = new StringAllocator(fullName).append('@').append(imapStore.toString()).toString();
         final FailFastError failFastError = FAIL_FAST.get(key);
         if (null == failFastError) {
             return;
@@ -195,7 +196,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
             imapFolder.open(desiredMode);
         } catch (final MessagingException e) {
             if (toUpperCase(e.getMessage()).indexOf("[INUSE]") >= 0) {
-                FAIL_FAST.put(imapFolder.getFullName() + '@' + imapStore.toString(), new FailFastError(e));
+                FAIL_FAST.put(new StringAllocator(imapFolder.getFullName()).append('@').append(imapStore.toString()).toString(), new FailFastError(e));
             }
             throw e;
         }
