@@ -132,6 +132,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
 
     private Set<String> propagateHostNames;
 
+    private boolean allowFolderCaches;
+
     /**
      * Initializes a new {@link IMAPProperties}
      */
@@ -173,6 +175,12 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
             notifyFullNames = tmp;
         }
 
+        {
+            final String allowFolderCachesStr = configuration.getProperty("com.openexchange.imap.allowFolderCaches", "true").trim();
+            allowFolderCaches = "true".equalsIgnoreCase(allowFolderCachesStr);
+            logBuilder.append("\tIMAP allow folder caches: ").append(allowFolderCaches).append('\n');
+        }
+
         {
             final String imapSortStr = configuration.getProperty("com.openexchange.imap.imapSort", "application").trim();
             imapSort = "imap".equalsIgnoreCase(imapSortStr);
@@ -560,4 +568,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         return mailProperties.isWatcherShallClose();
     }
 
+    @Override
+    public boolean allowFolderCaches() {
+        return allowFolderCaches;
+    }
 }
